<?php
/**
 * @package TopProductsDataTable
 * @author TechVillage <support@techvill.org>
 * @contributor Sakawat Hossain Rony <[sakawat.techvill@gmail.com]>
 * @created 23-08-2023
 */
namespace Modules\Affiliate\DataTables;

use App\DataTables\DataTable;
use Modules\Affiliate\Entities\Referral;

class TopProductsDataTable extends DataTable
{
    protected $userId;
    /*
    * DataTable Ajax
    *
    * @return \Yajra\DataTables\DataTableAbstract|\Yajra\DataTables\DataTables
    */
    public function ajax()
    {
        $referrals = $this->query();
        return datatables()
            ->of($referrals)

            ->editColumn('product', function ($referrals) {
                return $referrals->product?->name;
            })
            ->editColumn('total_purchase', function ($referrals) {
                return formatCurrencyAmount($referrals->total_purchase);
            })
            ->editColumn('sales', function ($referrals) {
                return formatNumber($referrals->sales_amount);
            })
            ->rawColumns(['product', 'total_purchase', 'sales'])
            ->make(true);
    }

    /*
    * DataTable Query
    *
    * @return mixed
    */
    public function query()
    {
        $userId = $this->getUserId();
        $referrals = Referral::where('affiliate_user_id', $userId)->whereNotNull('product_id')->where('sales_amount', '>', '0')->orderBy('sales_amount', 'DESC')->get();

        return $this->applyScopes($referrals);
    }

    /*
    * DataTable HTML
    *
    * @return \Yajra\DataTables\Html\Builder
    */
    public function html()
    {
        return $this->builder()
            ->addColumn(['data' => 'product', 'name' => 'product', 'title' => __('Product')])
            ->addColumn(['data' => 'total_purchase', 'name' => 'total_purchase', 'title' => __('Quantity')])
            ->addColumn(['data' => 'sales', 'name' => 'sales', 'title' => __('Sales')])
            ->parameters(dataTableOptions());
    }

    public function setUserId($id)
    {
        $this->userId = $id;
    }

    public function getUserId()
    {
        return $this->userId;
    }
}
