<?php

namespace Modules\Affiliate\DataTables;

use App\DataTables\DataTable;
use Modules\Affiliate\Entities\ReferralPurchase;

class UserReferralPurchaseDataTable extends DataTable
{
    protected $userId;
    /*
    * DataTable Ajax
    *
    * @return \Yajra\DataTables\DataTableAbstract|\Yajra\DataTables\DataTables
    */
    public function ajax()
    {
        $referrals = $this->query();
        return datatables()
            ->of($referrals)

            ->editColumn('date', function ($referrals) {
                return $referrals->format_created_at;
            })
            ->editColumn('order', function ($referrals) {
                return "#".$referrals->order?->reference;
            })
            ->editColumn('commission', function ($referrals) {
                return formatNumber($referrals->commission);
            })
            ->editColumn('customer', function ($referrals) {
                return $referrals->order?->user?->name;
            })
            ->editColumn('medium', function ($referrals) {
                return $referrals->medium;
            })
            ->editColumn('status', function ($referrals) {
                if ($referrals->status == 'Approve') {
                    return '<span class="badge theme-bg-active text-white f-12">' . $referrals->status .  '</span>';
                }

                return '<span class="badge theme-bg-pending text-white f-12">' . $referrals->status .  '</span>';
            })
            ->rawColumns(['date', 'order', 'commission', 'customer', 'medium', 'status'])
            ->make(true);
    }

    /*
    * DataTable Query
    *
    * @return mixed
    */
    public function query()
    {
        $userId = $this->getUserId();
        $referrals = ReferralPurchase::where('affiliate_user_id', $userId)->get();

        return $this->applyScopes($referrals);
    }

    /*
    * DataTable HTML
    *
    * @return \Yajra\DataTables\Html\Builder
    */
    public function html()
    {
        return $this->builder()
            ->addColumn(['data' => 'date', 'name' => 'date', 'title' => __('Date')])
            ->addColumn(['data' => 'order', 'name' => 'order', 'title' => __('Order')])
            ->addColumn(['data' => 'commission', 'name' => 'commission', 'title' => __('Commission')])
            ->addColumn(['data' => 'customer', 'name' => 'customer', 'title' => __('Customer')])
            ->addColumn(['data' => 'medium', 'name' => 'medium', 'title' => __('Medium')])
            ->addColumn(['data' => 'status', 'name' => 'status', 'title' => __('Status'), 'orderable' => false])
            ->parameters(dataTableOptions());
    }

    public function setUserId($id)
    {
        $this->userId = $id;
    }

    public function getUserId()
    {
        return $this->userId;
    }
}
