<?php

namespace Modules\Affiliate\Entities;

use Illuminate\Database\Eloquent\Model;
use Modules\Refund\Entities\Refund;

class CommissionLog extends Model
{
    protected $fillable = ['product_id', 'referral_purchase_id', 'amount'];

    /**
     * tag store
     *
     * @param $request
     * @return bool
     */
    public static function store($logs = [], $orderId)
    {
        $formattedData = [];
        if (is_array($logs) && count($logs) > 0) {
            foreach ($logs as $productId => $data) {

                $formattedData[] = [
                   'product_id' => $productId,
                   'order_id' =>  $orderId,
                   'data' => json_encode($data),
                ];
            }

            if (parent::insert($formattedData)) {
                return true;
            }
        }

        return false;
    }

    /**
     * commission refund
     *
     * @param $refundId
     * @param $status
     * @return true
     */
    public static function refund($refundId = null, $status = null)
    {
        if ($status == 'Accepted') {
            $refund = Refund::where('id', $refundId)->first();

            if (!empty($refund)) {
                $allRefunds = Refund::where('order_detail_id', $refund->order_detail_id)->count();

                if ($allRefunds == 1) {
                    self::decrementCommission($refund->orderDetail?->product_id, $refund->orderDetail);
                }
            }
        }

        return true;
    }


    /**
     * decrement commission if something wrong with specific product
     *
     * @param $productId
     * @param $orderId
     * @return void
     */
    public static function decrementCommission($productId, $orderDetails): void
    {
        $log = parent::where('product_id', $productId)->where('order_id', $orderDetails->order_id)->first();

        if (!$log) {
            return;
        }

        $commissions = json_decode($log->data, true);

        if (!is_array($commissions) || count($commissions) === 0) {
            return;
        }


        $oneOnly = false;

        foreach ($commissions as $affiliateUserId => $amount) {
            $user = AffiliateUser::find($affiliateUserId);

            if (!$user) {
                continue;
            }


            $user->decrementNetCommission($amount);

            $referralPurchase = $user->referralPurchases
                                ->where('order_id', $orderDetails->order_id)
                                ->first();

            if (!empty($referralPurchase)) {
                $referralPurchase->decrementCommission($amount);
            }

            if ($oneOnly) {
                continue;
            }


            $referral = $user->referral
                        ->where('product_id', $productId)
                        ->first();

            $oneOnly = true;

            if (!$referral) {
                continue;
            }


            $user->decrementRevenue(
                ($orderDetails->price * $orderDetails->quantity) + $orderDetails->tax_charge
            );

            $referral->decrementTotalPurchase($orderDetails->quantity);
            $referral->decrementTotalSalesAmout($orderDetails->price * $orderDetails->quantity);
        }
    }
}
