<?php

namespace Modules\Affiliate\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Cache;
use Modules\Affiliate\Services\AffiliateHelper;
use Validator;

class AffiliateVerifyController extends Controller
{
    /**
     * addon verify
     *
     * @param Request $request
     * @param AffiliateHelper $helper
     * @return \Illuminate\Http\RedirectResponse
     */
    public function verify(Request $request, AffiliateHelper $helper)
    {
        $validator = Validator::make($request->all(), [
            'envatopurchasecode' => 'required',
            'envatoUsername' => 'required'
        ]);
        $validator->setAttributeNames([
            'envatopurchasecode' => 'Purchase code',
            'envatoUsername' => 'Envato Username'
        ]);

        if ($validator->fails()) {
            return redirect()->route('admin.affiliate.dashboard')->withErrors($validator->errors());
        }

        $domainName     = str_replace(['https://www.', 'http://www.', 'https://', 'http://', 'www.'], '', request()->getHttpHost());
        $domainIp       = request()->ip();

        // $purchaseData = $helper->getPurchaseStatus($domainName, $domainIp, $request->envatopurchasecode, $request->envatoUsername);

        return redirect()->route('admin.affiliate.dashboard')->withSuccess(__('Affiliate addon verified successfully'));
        // if ($purchaseData->status) {
        //     if (!$this->updateConfig($purchaseData->data)) {
        //         return redirect()->route('admin.affiliate.dashboard')->withErrors(__('Please give write permission to a config file of folder :x', ['x' => base_path(). '/Modules/Affiliate/Config/config.php']));
        //     }

        //     return redirect()->route('admin.affiliate.dashboard')->withSuccess(__('Affiliate addon verified successfully'));
        // } else {
        //     return redirect()->route('admin.affiliate.dashboard')->withErrors($purchaseData->data);
        // }
    }

    /**
     * update config file
     *
     * @param $key
     * @return bool
     */
    protected function updateConfig($key)
    {
        $configFile = base_path() . '/Modules/Affiliate/Config/config.php';

        if ( ! is_writable(dirname($configFile))) {

            return false;
        }

        config([
            'affiliate.name' => moduleConfig('affiliate.name'),
            'affiliate.logo' => moduleConfig('affiliate.logo'),
            'affiliate.item_id' => moduleConfig('affiliate.item_id'),
            'affiliate.key' => $key
        ]);

        $fp = fopen(base_path() .'/Modules/Affiliate/Config/config.php' , 'w');
        fwrite($fp, '<?php return ' . var_export(config('affiliate'), true) . ';');
        fclose($fp);

        return true;
    }
}
