@extends('.site.layouts.app')
@section('page_title', __('Affiliate Registration'))
@section('css')
    <link rel="stylesheet" href="{{ asset('public/datta-able/plugins/select2/css/select2.min.css') }}">
@endsection
@section('content')
        <!-- component -->
    <div class="bg-gray-23 lg:bg-cover bg-center">
        <span><img class="3xl:h-full h-36" src="{{ asset('public/frontend/assets/img/be-seller/registration-header-bg.svg') }}" alt="{{ __('Image') }}"></span>
    </div>
    @php
        $affiliateUser = auth()->user()->affiliateUser()->first();
        $form = \Modules\FormBuilder\Entities\Form::where('type', 'affiliate')->first();
    @endphp
    <div class="3xl:mx-470p 2xl:mx-64 xl:mx-32 md:mx-20 mx-5 mb-70p 3xl:-mt-132p -mt-28 relative border border-gray-2 bg-white rounded-lg {{ !empty($affiliateUser) && $affiliateUser->status == 'Pending' ? 'p-10' : '' }}">
        <p class="lg:mt-12 mt-6 text-gray-10 lg:text-lg text-xs dm-sans font-medium text-center">
            {{ __('Register now with easy steps!') }}</p>
        <p class="lg:mt-2.5 mt-2 text-gray-12 lg:text-28 text-19 dm-bold font-bold uppercase text-center px-5 lg:px-0">
            {{ $form->name }}</p>
        <div class="primary-bg-color lg:h-1 h-3p rounded-lg lg:w-93p w-60p mx-auto lg:mt-3.5 mt-3"></div>
        <p class="lg:mt-8 mt-22p roboto-medium font-medium text-gray-10 lg:text-sm text-xs text-center lg:px-52 px-15p">
            @if(empty($affiliateUser))
            {{ __('Note: Please make sure to fill in the form with your actual information or else your account may become banned or suspended.') }}
            @elseif(!empty($affiliateUser) && $affiliateUser->status == 'Pending')
                {{ __("Your submitted form is under review. Please wait for confirmation.") }}..
            @endif

        </p>
        @error('fail')
        <div class="flex justify-center">
            <p class="password-validation-error block text-center text-11 mt-1 text-red-500 p-2 font-bold text-sm mb-2">{{ $message }}</p>
        </div>
        @enderror
        @php
            $colors = ['fail' => 'text-red-500', 'info' => 'text-red-500', 'success' => 'text-green-1']
        @endphp
        @foreach (['success', 'fail', 'info'] as $msg)
            @if ($message = Session::get($msg))
                <div class="flex justify-center">
                    <p class="{{ $colors[$msg] }} block text-center text-11 mt-1 p-2 font-bold text-sm mb-2">{{ $message }}</p>
                </div>
            @endif
        @endforeach
    @if(empty($affiliateUser))
        <form method="post" action="{{ route('site.affiliate.registration') }}" class="lg:mt-8 mt-30p xl:mx-130p lg:mx-70p mx-15p" enctype="multipart/form-data" onsubmit="return formValidation()">
            @csrf
            @error('name')
            <div class="flex justify-center">
                <p class="password-validation-error block text-center text-11 text-red-500 p-2 font-bold text-sm">{{ $message }}</p>
            </div>
            @enderror
            <div class="flex">
                <div class="primary-bg-color w-2p lg:h-23p h-5 mt-2p {{ languageDirection() == 'ltr' ? 'mr-2' : 'ml-2' }}"> </div>
                <p class="text-gray-12 mb-5 uppercase dm-bold font-bold lg:text-lg text-base">{{ __('Basic Details') }}
                </p>
            </div>
            <div class="grid grid-cols-1 gap-0">
                @includeIf('affiliate::site.affiliate_form')
            </div>

            <div class="flex justify-center items-center mb-8 lg:mt-10 mt-8">
                <button class="flex xl:mr-8 md:mx-0 process-goto relative mx-auto text-base w-52 transition duration-150 ease-in-out h-50p justify-center text-center rounded-sm 2 items-center bg-gray-12 primary-bg-hover dm-bold font-bold text-white hover:text-gray-12" onclick="formValidation()" id="btnSubmits">{{ __('Register') }}
                    <svg class="{{ languageDirection() == 'ltr' ? 'ml-1.5' : 'mr-1.5' }} neg-transition-scale relative" xmlns="http://www.w3.org/2000/svg" width="13" height="8"
                         viewBox="0 0 13 8" fill="none">
                        <path fill-rule="evenodd" clip-rule="evenodd"
                              d="M8.92948 0L7.75346 1.20177L9.66016 3.15022H1.68894C1.22968 3.15022 0.857371 3.53068 0.857371 4C0.857371 4.46932 1.22968 4.84978 1.68894 4.84978H9.66016L7.75346 6.79823L8.92948 8L12.8438 4L8.92948 0Z"
                              fill="currentColor" />
                    </svg>
                </button>
            </div>
        </form>
    @endif
    </div>
@endsection

@section('js')
    <script src="{{ asset('public/datta-able/plugins/select2/js/select2.full.min.js') }}"></script>
@endsection
