<?php

namespace Modules\Affiliate\Services;

use App\Models\RoleUser;
use App\Services\Mail\TechVillageMail;
use Modules\Affiliate\Entities\ReferralPurchase;

class ReferralMailService extends TechVillageMail
{
    /**
     * Send mail to user
     * @param object $request
     * @return array $response
     */
    public function send($order)
    {
        $email = $this->getTemplate(preference('dflt_lang'), 'referral');

        if (!$email['status']) {
            return $email;
        }

        $referralPurchase = ReferralPurchase::where('order_id', $order->id);

        if ($referralPurchase->exists()) {
            $referralPurchase = $referralPurchase->get();
            $userName = [];
            $amount = [];
            foreach ($referralPurchase as $purchase) {
                $userName[] = $purchase->user?->name;
                $amount[] = formatNumber($purchase->commission);
            }

            $subject = str_replace('{company_name}', preference('company_name'), $email->subject);
            $superAdmin = RoleUser::where('role_id', 1)->first();

            $data = [
                '{user_name}' => $superAdmin->users?->name,
                '{logo}' => $this->logo,
                '{company_name}' => preference('company_name'),
                '{support_mail}' => preference('company_email'),
                '{ref_user}' => implode(',', $userName),
                '{com_amount}' => implode(',', $amount),
                '{affiliate_panel}' => route('admin.affiliate.dashboard')
            ];

            $message = str_replace(array_keys($data), $data, $email->body);

            return $this->email->sendEmail($superAdmin->users?->email, $subject, $message, null, preference('company_name'));
        }
    }
}
